Class: Aws::PcaConnectorScep::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PcaConnectorScep::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-pcaconnectorscep/client.rb,
sig/client.rbs
Overview
An API client for PcaConnectorScep. To construct a client, you need to configure a :region and :credentials.
client = Aws::PcaConnectorScep::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateChallengeResponseSuccess, _CreateConnectorResponseSuccess, _GetChallengeMetadataResponseSuccess, _GetChallengePasswordResponseSuccess, _GetConnectorResponseSuccess, _ListChallengeMetadataResponseSuccess, _ListConnectorsResponseSuccess, _ListTagsForResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_challenge(params = {}) ⇒ Types::CreateChallengeResponse
For general-purpose connectors.
-
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a SCEP connector.
-
#delete_challenge(params = {}) ⇒ Struct
Deletes the specified [Challenge][1].
-
#delete_connector(params = {}) ⇒ Struct
Deletes the specified [Connector][1].
-
#get_challenge_metadata(params = {}) ⇒ Types::GetChallengeMetadataResponse
Retrieves the metadata for the specified [Challenge][1].
-
#get_challenge_password(params = {}) ⇒ Types::GetChallengePasswordResponse
Retrieves the challenge password for the specified [Challenge][1].
-
#get_connector(params = {}) ⇒ Types::GetConnectorResponse
Retrieves details about the specified [Connector][1].
-
#list_challenge_metadata(params = {}) ⇒ Types::ListChallengeMetadataResponse
Retrieves the challenge metadata for the specified ARN.
-
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Lists the connectors belonging to your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to your resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from your resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1047 1048 1049 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 1047 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1050 1051 1052 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 1050 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 1020 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PcaConnectorScep') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-pcaconnectorscep' context[:gem_version] = '1.33.0' Seahorse::Client::Request.new(handlers, context) end |
#create_challenge(params = {}) ⇒ Types::CreateChallengeResponse
For general-purpose connectors. Creates a challenge password for the specified connector. The SCEP protocol uses a challenge password to authenticate a request before issuing a certificate from a certificate authority (CA). Your SCEP clients include the challenge password as part of their certificate request to Connector for SCEP. To retrieve the connector Amazon Resource Names (ARNs) for the connectors in your account, call ListConnectors.
To create additional challenge passwords for the connector, call
CreateChallenge again. We recommend frequently rotating your
challenge passwords.
86 |
# File 'sig/client.rbs', line 86
def create_challenge: (
|
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a SCEP connector. A SCEP connector links Amazon Web Services Private Certificate Authority to your SCEP-compatible devices and mobile device management (MDM) systems. Before you create a connector, you must complete a set of prerequisites, including creation of a private certificate authority (CA) to use with this connector. For more information, see Connector for SCEP prerequisites.
98 |
# File 'sig/client.rbs', line 98
def create_connector: (
|
#delete_challenge(params = {}) ⇒ Struct
Deletes the specified Challenge.
113 |
# File 'sig/client.rbs', line 113
def delete_challenge: (
|
#delete_connector(params = {}) ⇒ Struct
Deletes the specified Connector. This operation also deletes any challenges associated with the connector.
119 |
# File 'sig/client.rbs', line 119
def delete_connector: (
|
#get_challenge_metadata(params = {}) ⇒ Types::GetChallengeMetadataResponse
Retrieves the metadata for the specified Challenge.
129 |
# File 'sig/client.rbs', line 129
def get_challenge_metadata: (
|
#get_challenge_password(params = {}) ⇒ Types::GetChallengePasswordResponse
Retrieves the challenge password for the specified Challenge.
139 |
# File 'sig/client.rbs', line 139
def get_challenge_password: (
|
#get_connector(params = {}) ⇒ Types::GetConnectorResponse
Retrieves details about the specified Connector. Calling this action returns important details about the connector, such as the public SCEP URL where your clients can request certificates.
149 |
# File 'sig/client.rbs', line 149
def get_connector: (
|
#list_challenge_metadata(params = {}) ⇒ Types::ListChallengeMetadataResponse
Retrieves the challenge metadata for the specified ARN.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
160 |
# File 'sig/client.rbs', line 160
def list_challenge_metadata: (
|
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Lists the connectors belonging to your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
173 |
# File 'sig/client.rbs', line 173
def list_connectors: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource. Tags are key-value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to "customer" and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
184 |
# File 'sig/client.rbs', line 184
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to your resource.
190 |
# File 'sig/client.rbs', line 190
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from your resource.
197 |
# File 'sig/client.rbs', line 197
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1040 1041 1042 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 1040 def waiter_names [] end |