Class: Aws::PcaConnectorScep::Types::CreateChallengeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PcaConnectorScep::Types::CreateChallengeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcaconnectorscep/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Custom string that can be used to distinguish between calls to the [CreateChallenge][1] action.
-
#connector_arn ⇒ String
The Amazon Resource Name (ARN) of the connector that you want to create a challenge for.
-
#tags ⇒ Hash<String,String>
The key-value pairs to associate with the resource.
Instance Attribute Details
#client_token ⇒ String
Custom string that can be used to distinguish between calls to the
CreateChallenge action. Client tokens for CreateChallenge
time out after five minutes. Therefore, if you call
CreateChallenge multiple times with the same client token within
five minutes, Connector for SCEP recognizes that you are requesting
only one challenge and will only respond with one. If you change the
client token for each call, Connector for SCEP recognizes that you
are requesting multiple challenge passwords.
A suitable default value is auto-generated. You should normally not need to pass this option.
341 342 343 344 345 346 347 |
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 341 class CreateChallengeRequest < Struct.new( :connector_arn, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#connector_arn ⇒ String
The Amazon Resource Name (ARN) of the connector that you want to create a challenge for.
341 342 343 344 345 346 347 |
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 341 class CreateChallengeRequest < Struct.new( :connector_arn, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The key-value pairs to associate with the resource.
341 342 343 344 345 346 347 |
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 341 class CreateChallengeRequest < Struct.new( :connector_arn, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |