Class: Aws::PcaConnectorScep::Types::IntuneConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcaconnectorscep/types.rb

Overview

Contains configuration details for use with Microsoft Intune. For information about using Connector for SCEP for Microsoft Intune, see Using Connector for SCEP for Microsoft Intune.

When you use Connector for SCEP for Microsoft Intune, certain functionalities are enabled by accessing Microsoft Intune through the Microsoft API. Your use of the Connector for SCEP and accompanying Amazon Web Services services doesn't remove your need to have a valid license for your use of the Microsoft Intune service. You should also review the Microsoft Intune® App Protection Policies.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#azure_application_idString

The directory (tenant) ID from your Microsoft Entra ID app registration.

Returns:



588
589
590
591
592
593
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 588

class IntuneConfiguration < Struct.new(
  :azure_application_id,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end

#domainString

The primary domain from your Microsoft Entra ID app registration.

Returns:



588
589
590
591
592
593
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 588

class IntuneConfiguration < Struct.new(
  :azure_application_id,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end