Class: Aws::PcaConnectorScep::Types::ResourceNotFoundException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcaconnectorscep/types.rb

Overview

The operation tried to access a nonexistent resource. The resource might be incorrectly specified, or it might have a status other than ACTIVE.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


810
811
812
813
814
815
816
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 810

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The identifier of the Amazon Web Services resource.

Returns:

  • (String)


810
811
812
813
814
815
816
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 810

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The resource type, which can be either Connector or Challenge.

Returns:

  • (String)


810
811
812
813
814
815
816
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 810

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_id,
  :resource_type)
  SENSITIVE = []
  include Aws::Structure
end