Class: Aws::PcaConnectorScep::Types::ServiceQuotaExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcaconnectorscep/types.rb

Overview

The request would cause a service quota to be exceeded.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 837

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end

#quota_codeString

The quota identifier.

Returns:

  • (String)


837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 837

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The resource type, which can be either Connector or Challenge.

Returns:

  • (String)


837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 837

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end

#service_codeString

Identifies the originating service.

Returns:

  • (String)


837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 837

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end