Class: Aws::PcaConnectorScep::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PcaConnectorScep::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-pcaconnectorscep/client.rb
Overview
An API client for PcaConnectorScep. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::PcaConnectorScep::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_challenge(params = {}) ⇒ Types::CreateChallengeResponse
For general-purpose connectors.
-
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a SCEP connector.
-
#delete_challenge(params = {}) ⇒ Struct
Deletes the specified [Challenge].
-
#delete_connector(params = {}) ⇒ Struct
Deletes the specified [Connector].
-
#get_challenge_metadata(params = {}) ⇒ Types::GetChallengeMetadataResponse
Retrieves the metadata for the specified [Challenge].
-
#get_challenge_password(params = {}) ⇒ Types::GetChallengePasswordResponse
Retrieves the challenge password for the specified [Challenge].
-
#get_connector(params = {}) ⇒ Types::GetConnectorResponse
Retrieves details about the specified [Connector].
-
#list_challenge_metadata(params = {}) ⇒ Types::ListChallengeMetadataResponse
Retrieves the challenge metadata for the specified ARN.
-
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Lists the connectors belonging to your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to your resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from your resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1049 1050 1051 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 1049 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1052 1053 1054 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 1052 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 1022 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PcaConnectorScep') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-pcaconnectorscep' context[:gem_version] = '1.30.0' Seahorse::Client::Request.new(handlers, context) end |
#create_challenge(params = {}) ⇒ Types::CreateChallengeResponse
For general-purpose connectors. Creates a *challenge password* for the specified connector. The SCEP protocol uses a challenge password to authenticate a request before issuing a certificate from a certificate authority (CA). Your SCEP clients include the challenge password as part of their certificate request to Connector for SCEP. To retrieve the connector Amazon Resource Names (ARNs) for the connectors in your account, call [ListConnectors].
To create additional challenge passwords for the connector, call ‘CreateChallenge` again. We recommend frequently rotating your challenge passwords.
[1]: docs.aws.amazon.com/pca-connector-scep/latest/APIReference/API_ListConnectors.html
545 546 547 548 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 545 def create_challenge(params = {}, = {}) req = build_request(:create_challenge, params) req.send_request() end |
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a SCEP connector. A SCEP connector links Amazon Web Services Private Certificate Authority to your SCEP-compatible devices and mobile device management (MDM) systems. Before you create a connector, you must complete a set of prerequisites, including creation of a private certificate authority (CA) to use with this connector. For more information, see [Connector for SCEP prerequisites].
651 652 653 654 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 651 def create_connector(params = {}, = {}) req = build_request(:create_connector, params) req.send_request() end |
#delete_challenge(params = {}) ⇒ Struct
Deletes the specified [Challenge].
[1]: docs.aws.amazon.com/pca-connector-scep/latest/APIReference/API_Challenge.html
677 678 679 680 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 677 def delete_challenge(params = {}, = {}) req = build_request(:delete_challenge, params) req.send_request() end |
#delete_connector(params = {}) ⇒ Struct
Deletes the specified [Connector]. This operation also deletes any challenges associated with the connector.
[1]: docs.aws.amazon.com/pca-connector-scep/latest/APIReference/API_Connector.html
704 705 706 707 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 704 def delete_connector(params = {}, = {}) req = build_request(:delete_connector, params) req.send_request() end |
#get_challenge_metadata(params = {}) ⇒ Types::GetChallengeMetadataResponse
Retrieves the metadata for the specified [Challenge].
[1]: docs.aws.amazon.com/pca-connector-scep/latest/APIReference/API_Challenge.html
739 740 741 742 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 739 def (params = {}, = {}) req = build_request(:get_challenge_metadata, params) req.send_request() end |
#get_challenge_password(params = {}) ⇒ Types::GetChallengePasswordResponse
Retrieves the challenge password for the specified [Challenge].
[1]: docs.aws.amazon.com/pca-connector-scep/latest/APIReference/API_Challenge.html
771 772 773 774 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 771 def get_challenge_password(params = {}, = {}) req = build_request(:get_challenge_password, params) req.send_request() end |
#get_connector(params = {}) ⇒ Types::GetConnectorResponse
Retrieves details about the specified [Connector]. Calling this action returns important details about the connector, such as the public SCEP URL where your clients can request certificates.
[1]: docs.aws.amazon.com/pca-connector-scep/latest/APIReference/API_Connector.html
817 818 819 820 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 817 def get_connector(params = {}, = {}) req = build_request(:get_connector, params) req.send_request() end |
#list_challenge_metadata(params = {}) ⇒ Types::ListChallengeMetadataResponse
Retrieves the challenge metadata for the specified ARN.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
868 869 870 871 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 868 def (params = {}, = {}) req = build_request(:list_challenge_metadata, params) req.send_request() end |
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Lists the connectors belonging to your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
924 925 926 927 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 924 def list_connectors(params = {}, = {}) req = build_request(:list_connectors, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource. Tags are key-value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to “customer” and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
958 959 960 961 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 958 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to your resource.
986 987 988 989 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 986 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from your resource.
1013 1014 1015 1016 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 1013 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1042 1043 1044 |
# File 'lib/aws-sdk-pcaconnectorscep/client.rb', line 1042 def waiter_names [] end |