Class: Aws::PcaConnectorScep::Types::ResourceNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::PcaConnectorScep::Types::ResourceNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcaconnectorscep/types.rb
Overview
The operation tried to access a nonexistent resource. The resource
might be incorrectly specified, or it might have a status other than
ACTIVE.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#resource_id ⇒ String
The identifier of the Amazon Web Services resource.
-
#resource_type ⇒ String
The resource type, which can be either
ConnectororChallenge.
Instance Attribute Details
#message ⇒ String
810 811 812 813 814 815 816 |
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 810 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The identifier of the Amazon Web Services resource.
810 811 812 813 814 815 816 |
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 810 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The resource type, which can be either Connector or Challenge.
810 811 812 813 814 815 816 |
# File 'lib/aws-sdk-pcaconnectorscep/types.rb', line 810 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |